Seizure: Download Twitch VODs
=============================
.. image:: https://travis-ci.org/ShaneDrury/seizure.svg?branch=master
    :target: https://travis-ci.org/ShaneDrury/seizure
    
Seizure is a library that facilitates downloading Twitch VODs. 

.. code-block:: bash

    $ seizure 608495073
    $ seizure http://www.twitch.tv/gamesdonequick/b/609886511

Installation
------------
To install Seizure, simply:

.. code-block:: bash

    $ pip install seizure

Usage
-----
.. code-block:: bash

    $ seizure <video_code> [<video_code> ...]
